==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/sk_SK.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivita",
    "Personal activity feed for %s" : "Prehľad aktivít pre používateľa %s",
    "Your feed URL is invalid" : "Váš kanál URL je neplatný",
    "Your settings have been updated." : "Vaše nastavenia boli aktualizované.",
    "Mail" : "Pošta",
    "Stream" : "Stream",
    "This stream will show events like additions, changes & shares" : "Tento dátový prúd bude zobrazovať udalosti ako pridanie, zmeny a zdieľanie",
    "There are no events for this filter" : "Pre tieto kritériá nie sú žiadne udalosti",
    "Activity notification" : "Upozornenia na aktivity",
    "All Activities" : "Všetky aktivity",
    "Activities by you" : "Vaše aktivity",
    "Activities by others" : "Aktivity ostatných",
    "\"remote user\"" : "\"vzdialený používateľ\"",
    "in %s" : "v %s",
    "%s and %s" : "%s a %s",
    ", " : ", ",
    "_%s and %n more_::_%s and %n more_" : ["%s a %n ďalších","%s a %n ďalších","%s a %n ďalších"],
    "Hello %s," : "Ahoj %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* a %n ďalší ","* a %n ďalšie ","* a %n ďalších "],
    "Notifications" : "Oznámenia",
    "List your own actions in the stream" : "Zobrazovať vlastné činnosti v zozname",
    "Notify about your own actions via email" : "Poslať oznámenie o vlastnej činnosti emailom",
    "You need to set up your email address before you can receive notification emails." : "Ak chcete dostávať oznámenia emailom, musíte najskôr vyplniť vašu emailovú adresu.",
    "Send emails:" : "Odoslať emaily:",
    "Hourly" : "Každú hodinu",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Activity feed" : "Prehľad aktivít",
    "Enable RSS feed" : "Povoliť RSS kanál",
    "No activity yet" : "Zatiaľ žiadne aktivity.",
    "No more events to load" : "Žiadne ďalšie udalosti na načítanie",
    "Files" : "Súbory"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/sk_SK.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivita",
    "Personal activity feed for %s" : "Prehľad aktivít pre používateľa %s",
    "Your feed URL is invalid" : "Váš kanál URL je neplatný",
    "Your settings have been updated." : "Vaše nastavenia boli aktualizované.",
    "Mail" : "Pošta",
    "Stream" : "Stream",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Tento dátový prúd bude zobrazovať udalosti ako pridanie, zmeny a zdieľanie",
    "There are no events for this filter" : "Pre tieto kritériá nie sú žiadne udalosti",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "\"remote user\"" : "\"vzdialený používateľ\"",
    "Activity notification" : "Upozornenia na aktivity",
    "All Activities" : "Všetky aktivity",
    "Activities by you" : "Vaše aktivity",
    "Activities by others" : "Aktivity ostatných",
    "%s and %s" : "%s a %s",
    "Hello %s," : "Ahoj %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* a %n ďalší ","* a %n ďalšie ","* a %n ďalších "],
    "List your own actions in the stream" : "Zobrazovať vlastné činnosti v zozname",
    "Notify about your own actions via email" : "Poslať oznámenie o vlastnej činnosti emailom",
    "You need to set up your email address before you can receive notification emails." : "Ak chcete dostávať oznámenia emailom, musíte najskôr vyplniť vašu emailovú adresu.",
    "Send emails:" : "Odoslať emaily:",
    "Hourly" : "Každú hodinu",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Activity feed" : "Prehľad aktivít",
    "Enable RSS feed" : "Povoliť RSS kanál",
    "No activity yet" : "Zatiaľ žiadne aktivity.",
    "No more events to load" : "Žiadne ďalšie udalosti na načítanie",
    "Files" : "Súbory"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
